@@ -10,15 +10,14 @@ class AbstractNearestNeighborsComputer(object):
 
 class ScikitNearestNeighbors(AbstractNearestNeighborsComputer):
 
-    def __init__(self, n_neighbors, nn_n_jobs):
-        self.n_neighbors = n_neighbors
+    def __init__(self, nn_n_jobs):
         self.nn_n_jobs = nn_n_jobs
         self.nn_object = NearestNeighbors(
             algorithm="brute", metric="precomputed",
             n_jobs=self.nn_n_jobs)
 
-    def __call__(self, affinity_mat):
-        return self.nn_object.fit(np.max(affinity_mat) - affinity_mat).kneighbors(
-                  X=np.max(affinity_mat) - affinity_mat, 
-                  n_neighbors=min(self.n_neighbors+1, len(affinity_mat)),
+    def __call__(self, n_neighbors, affinity_mat):
+        return self.nn_object.fit(np.max(affinity_mat)-affinity_mat).\
+                kneighbors(X=np.max(affinity_mat) - affinity_mat, 
+                  n_neighbors=min(n_neighbors+1, len(affinity_mat)),
                   return_distance=False)
